[
          {
            'name' => 'Xorg::Device::Nvidia',
            'element' => [
                           'TwinView',
                           {
                             'value_type' => 'boolean',
                             'upstream_default' => 0,
                             'type' => 'leaf'
                           },
                           'MetaModes',
                           {
                             'value_type' => 'uniline',
                             'type' => 'leaf',
                             'description' => 'Incomplete model. TBD'
                           },
                           'CrtcNumber',
                           {
                             'value_type' => 'integer',
                             'type' => 'leaf'
                           }
                         ]
          }
        ]
;
